summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsandra <sandra@138bc75d-0d04-0410-961f-82ee72b054a4>2015-06-05 16:01:45 +0000
committersandra <sandra@138bc75d-0d04-0410-961f-82ee72b054a4>2015-06-05 16:01:45 +0000
commitf855d85abdc16c2ac87a0855ed209683d4380ce8 (patch)
tree15023f0d1cd48d9d932c65ea5f94bd5039b57a4d
parent73951be736c1bebe57b95f6694a00dc0ed88c380 (diff)
downloadgcc-f855d85abdc16c2ac87a0855ed209683d4380ce8.tar.gz
2015-06-05 Julian Brown <julian@codesourcery.com>
Sandra Loosemore <sandra@codesourcery.com> gcc/ * config/print-sysroot-suffix.sh: Handle MULTILIB_REUSE settings. * config/t-sysroot-suffix (sysroot-suffix.h): Pass MULTILIB_REUSE to print-sysroot-suffix.sh script. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@224156 138bc75d-0d04-0410-961f-82ee72b054a4
-rw-r--r--gcc/ChangeLog7
-rw-r--r--gcc/config/print-sysroot-suffix.sh16
-rw-r--r--gcc/config/t-sysroot-suffix2
3 files changed, 21 insertions, 4 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index d641111dc12..cb1339a2886 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,10 @@
+2015-06-05 Julian Brown <julian@codesourcery.com>
+ Sandra Loosemore <sandra@codesourcery.com>
+
+ * config/print-sysroot-suffix.sh: Handle MULTILIB_REUSE settings.
+ * config/t-sysroot-suffix (sysroot-suffix.h): Pass MULTILIB_REUSE
+ to print-sysroot-suffix.sh script.
+
2015-06-05 Tom de Vries <tom@codesourcery.com>
merge from gomp4 branch:
diff --git a/gcc/config/t-sysroot-suffix b/gcc/config/t-sysroot-suffix
index 08b4f949e3c..79d76e792d7 100644
--- a/gcc/config/t-sysroot-suffix
+++ b/gcc/config/t-sysroot-suffix
@@ -3,5 +3,5 @@
sysroot-suffix.h: $(srcdir)/config/print-sysroot-suffix.sh
$(SHELL) $(srcdir)/config/print-sysroot-suffix.sh \
"$(MULTILIB_OSDIRNAMES)" "$(MULTILIB_OPTIONS)" \
- "$(MULTILIB_MATCHES)" > tmp-sysroot-suffix.h
+ "$(MULTILIB_MATCHES)" "$(MULTILIB_REUSE)" > tmp-sysroot-suffix.h
mv tmp-sysroot-suffix.h $@
diff --git a/gcc/config/print-sysroot-suffix.sh b/gcc/config/print-sysroot-suffix.sh
index 4080aaf85df..3f8bd94d794 100644
--- a/gcc/config/print-sysroot-suffix.sh
+++ b/gcc/config/print-sysroot-suffix.sh
@@ -1,6 +1,7 @@
#! /bin/sh
# Script to generate SYSROOT_SUFFIX_SPEC equivalent to MULTILIB_OSDIRNAMES
# Arguments are MULTILIB_OSDIRNAMES, MULTILIB_OPTIONS and MULTILIB_MATCHES.
# Copyright (C) 2009-2015 Free Software Foundation, Inc.
@@ -29,10 +30,11 @@
# MULTILIB_OSDIRNAMES \
# MULTILIB_OPTIONS \
# MULTILIB_MATCHES \
+# MULTILIB_REUSE
# > t-sysroot-suffix.h
# The three options exactly correspond to the variables of the same
# names defined in the tmake_file fragments.
# Example:
# sh ./gcc/config/print-sysroot-suffix.sh "a=A" "a b/c/d" ""
@@ -54,6 +56,7 @@ set -e
dirnames="$1"
options="$2"
matches="$3"
+reuse="$4"
cat > print-sysroot-suffix3.sh <<\EOF
#! /bin/sh
@@ -80,7 +83,14 @@ shift 2
n="\" \\
$padding\""
if [ $# = 0 ]; then
+ case $optstring in
EOF
+for x in $reuse; do
+ l=`echo $x | sed -e 's/=.*$//' -e 's/\./=/g'`
+ r=`echo $x | sed -e 's/^.*=//' -e 's/\./=/g'`
+ echo "/$r/) optstring=\"/$l/\" ;;" >> print-sysroot-suffix2.sh
+done
+echo " esac" >> print-sysroot-suffix2.sh
pat=
for x in $dirnames; do
@@ -1,6 +1,7 @@
#! /bin/sh
# Script to generate SYSROOT_SUFFIX_SPEC equivalent to MULTILIB_OSDIRNAMES
-# Arguments are MULTILIB_OSDIRNAMES, MULTILIB_OPTIONS and MULTILIB_MATCHES.
+# Arguments are MULTILIB_OSDIRNAMES, MULTILIB_OPTIONS, MULTILIB_MATCHES,
+# and MULTILIB_REUSE.
# Copyright (C) 2009-2015 Free Software Foundation, Inc.
@@ -29,10 +30,11 @@
# > t-sysroot-suffix.h
-# The three options exactly correspond to the variables of the same
-# names defined in the tmake_file fragments.
+# The four options exactly correspond to the variables of the same
+# names defined in the t-sysroot-suffix tmake_file fragment.
# Example:
# sh ./gcc/config/print-sysroot-suffix.sh "a=A" "a b/c/d" ""